@@ -1,14 +1,14 @@
 /*
  *  datamodel.h  -  model independent access to calendar functions
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2019-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2019-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <KAlarmCal/KACalendar>
+#include "kalarmcalendar/kacalendar.h"
 
 class Resource;
 class ResourceListModel;
@@ -44,8 +44,8 @@ public:
     /** Return whether calendar migration/creation at initialisation has completed. */
     static bool isMigrationComplete();
 
-    /** Check for, and remove, any duplicate Akonadi resources, i.e. those which
-     *  use the same calendar file/directory.
+    /** Check for, and remove, any duplicate resources, i.e. those which use
+     *  the same calendar file/directory.
      */
     static void removeDuplicateResources();
 
@@ -68,5 +68,4 @@ public:
     static TemplateListModel* allTemplateListModel();
 };
 
-
 // vim: et sw=4:
